import {
  select,
  json,
  tree,
  cluster,
  hierarchy,
  linkRadial,
  zoom,
  event,
  stratify
} from 'd3';

const svg = select('svg');
const width = document.body.clientWidth;
const height = document.body.clientHeight;
const radius = width * 2;

const treeLayout = tree()
  .size([2 * Math.PI, radius]);

const zoomG = svg
    .attr('width', width)
    .attr('height', height)
  .append('g');

const g = zoomG.append('g')
    .attr('transform', `translate(${width / 2},${height / 2})`);

svg.call(zoom().on('zoom', () => {
  zoomG.attr('transform', event.transform);
}));

const buildHierarchy = data => {
  const ids = {};// '-99': true};
  
  data.forEach(d => {
    ids[d.id] = true;
  });
  data.forEach(d => {
    d.forkedFrom = ids[d.forkedFrom]
      ? d.forkedFrom
      : '-99';
  });
  data.push({id: '-99'});
  
  
  return stratify()
    .id(d => d.id)
    .parentId(d => d.forkedFrom)
    (data);
};

json('https://vizhub.com/api/visualization/metadata')
  .then(data => {
    const root = buildHierarchy(data);
    const links = treeLayout(root).links();
    const linkPathGenerator = linkRadial()
      .angle(d => d.x)
      .radius(d => d.y);
  
    g.selectAll('path').data(links)
      .enter().append('path')
        .attr('d', linkPathGenerator);
  
    // const width = 2;
    // const height = width * 500 / 960;
  //   g.selectAll('image').data(root.descendants())
  //     .enter().append('image')
  //       .attr('x', d => d.y - width / 2)
  //       .attr('y', d => d.x - height / 2)
  //       .attr('width', width)
  //       .attr('href', (d, i) => `/api/visualization/thumbnail/${d.id}.png`)
   });